### Name: GarchModelling
### Title: Univariate GARCH Time Series Modelling
### Aliases: GarchModelling fGARCH fAPARCH garchSim garchFit aparchSim
###   aparchFit predict.fGARCH print.fGARCH summary.fGARCH
###   print.summary.fGARCH plot.fGARCH fitted.values.fGARCH
###   residuals.fGARCH predict.fAPARCH print.fAPARCH summary.fAPARCH
###   print.summary.fAPARCH plot.fAPARCH
### Keywords: models

### ** Examples

##  garchSim -
##  garchFit -
    xmpSeries("\nStart: Model Bollerslev's GARCH(1,1) Process >")
    # Simulate a time series of length 1000:
    ts = garchSim(model = list(omega = 1.0e-6, alpha = 0.1, beta = 0.8, 
      h0 = 1.0e-7), n = 1000)
    xmpSeries("\nNext: Estimate the parameters >")
    fit = garchFit(ts, order = c(1, 1))
    print(fit) 
    xmpSeries("\nNext: Summary and Diagnostic Analysis >")
    summary(fit)  

##  aparchSim -
##  aparchFit -
    xmpSeries("\nNext: Subset TS-GARCH(1,5[1,5]), delta fixed >")
    # Simulate a time series of length 1000:
    ts = aparchSim(model = list(omega = 1e-6, alpha = 0.1, gamma = 0, 
      alpha.lags=1, beta = c(0.5, 0.3), beta.lags = c(1, 5), delta = 1),
      innov = rnorm(5000), start.innov = rnorm(1000))
    par(mfrow = c(2, 2), cex = 0.6)
    ts.plot(ts, main = "Subset TS GARCH(1,5) - Mormal")
    acf(abs(ts), lag.max = 20)
    xmpSeries("\nNext: Estimate the parameters >")
    aparchFit(ts, order = list(alpha.lags = 1, beta.lags = c(1, 5), 
      delta = 1), opt = list(gamma = FALSE, delta = FALSE, disparm = FALSE), 
      doprint = FALSE)
    # For more examples type: xmpfSeries() ...



